
//
//  ZYAlbumViewController.m
//  ImagesMultiple
//
//  Created by 轶辉 on 16/10/14.
//  Copyright © 2016年 YiHui. All rights reserved.
//

#define screen_width [UIScreen mainScreen].bounds.size.width
#define screen_height [UIScreen mainScreen].bounds.size.height


#import "ZYAlbumViewController.h"
#import "ZYImagesViewController.h"
#import "ZYAlbumTableViewCell.h"
#import "ZYAlbumModel.h"

@interface ZYAlbumViewController ()<UITableViewDataSource, UITableViewDelegate>
@property (nonatomic, strong) UITableView    * albumTableview;
@property (nonatomic, strong) NSMutableArray * imagesArr;

@end

@implementation ZYAlbumViewController

- (void)viewDidLoad {
    [super viewDidLoad];
   
    [self setRightNavItem];
    [self getOriginalImages];
    [self getCameraImages];
    
}

// 添加右边取消按钮
- (void)setRightNavItem {
    
    self.title = @"获取相册";
    [self.view addSubview:self.albumTableview];
    
    UIButton * cancel = [UIButton buttonWithType:UIButtonTypeCustom];
    cancel.frame = CGRectMake(0, 0, 40, 20);
    [cancel setTitle:@"取消" forState:UIControlStateNormal];
    [cancel setTitleColor:[UIColor darkGrayColor] forState:UIControlStateNormal];
    [cancel addTarget:self action:@selector(cancelClick) forControlEvents:UIControlEventTouchUpInside];
    self.navigationItem.rightBarButtonItem = [[UIBarButtonItem alloc]initWithCustomView:cancel];
}

- (void)cancelClick {
    [self dismissViewControllerAnimated:YES completion:nil];
}

- (void)getCameraImages {
    // 获得相机胶卷
    PHAssetCollection * cameraRoll = [PHAssetCollection fetchAssetCollectionsWithType:PHAssetCollectionTypeSmartAlbum subtype:PHAssetCollectionSubtypeSmartAlbumUserLibrary options:nil].firstObject;

    // 遍历相机胶卷
    [self enumerateAssetsInAssetCollection:cameraRoll original:NO];
}

- (void)getOriginalImages {
    // 获得所有的自定义相簿
    PHFetchResult<PHAssetCollection *> *assetCollections = [PHAssetCollection fetchAssetCollectionsWithType:PHAssetCollectionTypeAlbum subtype:PHAssetCollectionSubtypeAlbumRegular options:nil];
    
    // 遍历所有的自定义相簿
    for (PHAssetCollection * assetCollection in assetCollections) {
        [self enumerateAssetsInAssetCollection:assetCollection original:NO];
    }
}

- (void)enumerateAssetsInAssetCollection:(PHAssetCollection *)assetCollection original:(BOOL)original {
    
    PHImageRequestOptions * options = [[PHImageRequestOptions alloc] init];
    options.synchronous = YES;
    //options.resizeMode = PHImageRequestOptionsResizeModeFast;
    
    // 获得某个相簿中的所有PHAsset对象
    PHFetchResult<PHAsset *> *assets = [PHAsset fetchAssetsInAssetCollection:assetCollection options:nil];
    
  
    
    // 获取第一个PHAsset
    PHAsset * asset = assets.firstObject;
    
    // 是否要原图
    CGSize size = original ? CGSizeMake(asset.pixelWidth, asset.pixelHeight) : CGSizeZero;
    
    [[PHImageManager defaultManager] requestImageForAsset:asset targetSize:size contentMode:PHImageContentModeDefault options:options resultHandler:^(UIImage * _Nullable result, NSDictionary * _Nullable info) {
        
        
        if (result) {
            
            
            
            ZYAlbumModel * model = [[ZYAlbumModel alloc]init];
            model.image = result;
            model.assets = assets;
            model.photoName = assetCollection.localizedTitle;
            [self.imagesArr addObject:model];
            [self.albumTableview reloadData];
        }
    }];
}



- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return self.imagesArr.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    ZYAlbumTableViewCell * cell = [ZYAlbumTableViewCell setZYAlbumTableViewCell:tableView];
    cell.model = self.imagesArr[indexPath.row];
    return cell;
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    ZYImagesViewController * imagesVc = [[ZYImagesViewController alloc]init];
    ZYAlbumModel * model = self.imagesArr[indexPath.row];
    imagesVc.maxImages   = self.maxImages;
    imagesVc.assets      = model.assets;
    [self.navigationController pushViewController:imagesVc animated:YES];
}

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath {
    return 70;
}

// 懒加载
- (UITableView *)albumTableview{
    if (!_albumTableview) {
        _albumTableview = [[UITableView alloc] initWithFrame:CGRectMake(0, 0, screen_width, screen_height) style:UITableViewStylePlain];
        _albumTableview.delegate = self;
        _albumTableview.dataSource = self;
        _albumTableview.separatorStyle = UITableViewCellSeparatorStyleNone;
        _albumTableview.backgroundColor = [UIColor whiteColor];
    }
    return _albumTableview;
}

- (NSMutableArray *)imagesArr{
    if (!_imagesArr) {
        _imagesArr = [NSMutableArray new];
    }
    return _imagesArr;
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    
}



@end
