
//
//  ZYCollectionView.m
//  赵杨图片轮播
//
//  Created by 轶辉 on 16/10/11.
//  Copyright © 2016年 YiHui. All rights reserved.
//
#define screen_width [UIScreen mainScreen].bounds.size.width
#define screen_height [UIScreen mainScreen].bounds.size.height

#import "ZYCollectionView.h"
#import "ZYImagesCollectionViewCell.h"
#define ZYCellID @"ZYCellID"

@interface ZYCollectionView ()<UICollectionViewDataSource, UICollectionViewDelegate, UICollectionViewDelegateFlowLayout>

@property (nonatomic, strong) UICollectionViewFlowLayout * layout;
@property (nonatomic, strong) UICollectionView           * collectionView;
@property (nonatomic, strong) UIImageView                * imageView;

@end


@implementation ZYCollectionView


- (instancetype)initWithFrame:(CGRect)frame {
    self = [super initWithFrame:frame];
    if (self) {
        [self createCycleView];
    }
    return self;
}

// 设置选中的item
- (void)setIndex:(NSInteger)index {
    _index = index;
    [_collectionView scrollToItemAtIndexPath:[NSIndexPath indexPathForItem:index inSection:0] atScrollPosition:0 animated:YES];
    
    // 获取高清图
    [self createBigImagesIndex:index];
}

- (void)createCycleView {
    if (_layout) {
        return;
    }
    _layout = [[UICollectionViewFlowLayout alloc]init];
    _layout.itemSize = CGSizeMake(self.frame.size.width, self.frame.size.height);
    _layout.minimumInteritemSpacing = 0;
    _layout.minimumLineSpacing      = 0;
    _layout.scrollDirection         = UICollectionViewScrollDirectionHorizontal;
    
    _collectionView = [[UICollectionView alloc]initWithFrame:self.bounds collectionViewLayout:_layout];
    _collectionView.backgroundColor = [UIColor blackColor];
    _collectionView.delegate = self;
    _collectionView.dataSource = self;
    _collectionView.pagingEnabled = YES;
    _collectionView.showsHorizontalScrollIndicator= NO;
    [self addSubview:_collectionView];
    
    [_collectionView registerClass:[ZYImagesCollectionViewCell class] forCellWithReuseIdentifier:ZYCellID];
}

- (void)createBigImagesIndex:(NSInteger)index {
    for (int i = 0; i < self.assets.count; i++) {
        if (i == index) {
            PHAsset * asset = self.assets[i];
            CGSize size = CGSizeMake(asset.pixelWidth, asset.pixelHeight);
            PHImageRequestOptions * options = [[PHImageRequestOptions alloc] init];
            options.synchronous = YES;
            [[PHImageManager defaultManager] requestImageForAsset:asset targetSize:size contentMode:PHImageContentModeDefault options:options resultHandler:^(UIImage * _Nullable result, NSDictionary * _Nullable info) {
                self.imageView.image = result;
                [self addSubview:self.imageView];
            }];
        }
    }
}

#pragma mark - UICollectionViewDataSource
- (void)scrollViewDidEndDecelerating:(UIScrollView *)scrollView {
    NSInteger index = scrollView.contentOffset.x / screen_width;
    
    // 获取当前图片的高清图 直接将原来的缩略图覆盖掉
    [self createBigImagesIndex:index];
    
}

// 当collevtionView滑动时 将imageView从父视图上移除
- (void)scrollViewDidScroll:(UIScrollView *)scrollView {
    [self.imageView removeFromSuperview];
}

- (NSInteger)collectionView:(UICollectionView *)collectionView numberOfItemsInSection:(NSInteger)section {
    return self.smaImagesArr.count;
}

- (UICollectionViewCell *)collectionView:(UICollectionView *)collectionView cellForItemAtIndexPath:(NSIndexPath *)indexPath {
    ZYImagesCollectionViewCell * cell = [collectionView dequeueReusableCellWithReuseIdentifier:ZYCellID forIndexPath:indexPath];
    cell.images = self.smaImagesArr[indexPath.row];
    return cell;
}

- (UIImageView *)imageView {
    if (!_imageView) {
        _imageView = [[UIImageView alloc]initWithFrame:self.bounds];
        _imageView.contentMode = UIViewContentModeScaleAspectFit;
    }
    return _imageView;
}

@end
