
//
//  ZYImagesMultipleView.m
//  ImagesMultiple
//
//  Created by 轶辉 on 16/10/14.
//  Copyright © 2016年 YiHui. All rights reserved.
//

#import "ZYImagesMultipleView.h"
#import "AppDelegate.h"
#import "ZYImageModel.h"
#import <Photos/Photos.h>

@interface ZYImagesMultipleView ()
@property (nonatomic, strong) UIImageView * pickImageView;
@property (nonatomic, strong) AppDelegate * app;
@end

@implementation ZYImagesMultipleView

- (instancetype)initWithFrame:(CGRect)frame {
    self = [super initWithFrame:frame];
    if (self) {
        CGFloat width = (frame.size.width - 50)/4;
        _pickImageView = [[UIImageView alloc]initWithFrame:CGRectMake(10, 10, width, width)];
        _pickImageView.image = [UIImage imageNamed:@"plus"];
        _pickImageView.tag = 100;
        _pickImageView.userInteractionEnabled = YES;
        
        // 添加手势
        UITapGestureRecognizer * tap =[[UITapGestureRecognizer alloc]initWithTarget:self action:@selector(tapClick)];
        [_pickImageView addGestureRecognizer:tap];
        [self addSubview:_pickImageView];
        
        // 添加通知、监听图片的选择是否结束
        [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(imagePickFinish) name:@"imagePickFinish" object:nil];
    }
    return self;
}

- (void)dealloc {
    // 销毁通知
    [[NSNotificationCenter defaultCenter]removeObserver:self];
}

- (void)imagePickFinish {
    
    // 将tag值不等于100的imageView删除掉 避免多余的控件残留在self上
    for (UIView * view in self.subviews) {
        if (view.tag != 100) {
            [view removeFromSuperview];
        }
    }
    
    int i = 0;
    CGFloat width = ([UIScreen mainScreen].bounds.size.width - 50)/4;
    for (ZYImageModel * model in self.app.imagesArr) {
        UIImageView * imageView = [[UIImageView alloc]initWithFrame:CGRectMake(10 + i % 4 * (width + 10), 10 + i / 4 * (width + 10), width, width)];
        imageView.contentMode = UIViewContentModeScaleAspectFill;
        imageView.clipsToBounds = YES;
        imageView.image = model.images;
        [self addSubview:imageView];
        i++;
    }
    
    NSInteger num = self.app.imagesArr.count;
    _pickImageView.frame = CGRectMake(10 + num % 4 * (width + 10), 10 + num / 4 * (width + 10), width, width);
}



//  相册的使用权限
- (BOOL)judgeHaveAlbumAuthority {
    // 判断相册使用权限
    PHAuthorizationStatus status = [PHPhotoLibrary authorizationStatus];
    if (status == PHAuthorizationStatusRestricted || status == PHAuthorizationStatusDenied) {
        return NO;
    }
    return YES;
}

// 调用协议
- (void)tapClick {
    
    [self judgeHaveAlbumAuthority];
    
    if ([self.delegate respondsToSelector:@selector(ZYImagesDelegateClick)]) {
        [self.delegate ZYImagesDelegateClick];
    }
}

// 懒加载
- (AppDelegate *)app {
    if (!_app) {
        _app = [UIApplication sharedApplication].delegate;
    }
    return _app;
}

@end
