
//
//  ZYImagesViewController.m
//  ImagesMultiple
//
//  Created by 轶辉 on 16/10/14.
//  Copyright © 2016年 YiHui. All rights reserved.
//

#define ZYImageID @"ZYImageID"
#define screen_width [UIScreen mainScreen].bounds.size.width
#define screen_height [UIScreen mainScreen].bounds.size.height

#import "ZYImagesViewController.h"
#import "ZYCollectionView.h"
#import "ZYImageViewCell.h"
#import "ZYImageModel.h"
#import "AppDelegate.h"

@interface ZYImagesViewController ()<UICollectionViewDataSource, UICollectionViewDelegate, UICollectionViewDelegateFlowLayout, ZYImageViewCellDelegate>

@property (nonatomic, strong) NSMutableArray * smaImagesArr;
@property (nonatomic, strong) NSMutableArray * bigImagesArr;

@property (nonatomic, strong) UICollectionViewFlowLayout * layout;

@property (nonatomic, strong) UICollectionView * cycleCollectionView;
@property (nonatomic, strong) ZYCollectionView * zyView;
@property (nonatomic, strong) UIButton * finishBtn;
@property (nonatomic, strong) AppDelegate * app;

@end

@implementation ZYImagesViewController

- (void)viewDidLoad {
    [super viewDidLoad];
  
    [self setRightNavBarItem];
    [self createCycleView];
    [self createData];
    
}

// 设置右边完成按钮
- (void)setRightNavBarItem {
    self.view.backgroundColor = [UIColor whiteColor];
    UIButton * rightBtn = [UIButton buttonWithType:UIButtonTypeCustom];
    rightBtn.frame = CGRectMake(0, 0, 40, 20);
    [rightBtn addTarget:self action:@selector(finishClick) forControlEvents:UIControlEventTouchUpInside];
    [rightBtn setTitle:@"完成" forState:UIControlStateNormal];
    [rightBtn setTitleColor:[UIColor darkGrayColor] forState:UIControlStateNormal];
    self.navigationItem.rightBarButtonItem = [[UIBarButtonItem alloc]initWithCustomView:rightBtn];
}

- (void)finishClick {
    self.app.imagesArr = self.bigImagesArr;
    [[NSNotificationCenter defaultCenter]postNotificationName:@"imagePickFinish" object:nil];
    [self dismissViewControllerAnimated:YES completion:nil];
}


- (void)createData {
    // 开辟一个子线程 以免出现卡顿的现象
    dispatch_queue_t queue = dispatch_queue_create("tk.bourne.testQueue", DISPATCH_QUEUE_CONCURRENT);
    dispatch_async(queue, ^{
        [self createSmallImages];
    });
}

// 获取相册的缩略图
- (void)createSmallImages {
    for (PHAsset * asset in self.assets) {
        
        CGSize size = CGSizeZero;
        
        PHImageRequestOptions * options = [[PHImageRequestOptions alloc] init];
       // options.resizeMode = PHImageRequestOptionsResizeModeFast;
       // options.deliveryMode = PHImageRequestOptionsDeliveryModeOpportunistic;
        options.synchronous = YES;
        
        [[PHImageManager defaultManager] requestImageForAsset:asset targetSize:size contentMode:PHImageContentModeDefault options:options resultHandler:^(UIImage * _Nullable result, NSDictionary * _Nullable info) {


            if (result) {
                [self.smaImagesArr addObject:result];
            }
            
            // 1.获得主队列  回到主线程，刷新列表
            dispatch_queue_t queue = dispatch_get_main_queue();
            // 2.添加任务到队列中 执行
            dispatch_async(queue, ^{
                [_cycleCollectionView reloadData];
            });
        }];
    }
}

- (void)createCycleView {
    if (_layout) {
        return;
    }
    _layout = [[UICollectionViewFlowLayout alloc]init];
    _layout.minimumInteritemSpacing = 5;
    _layout.minimumLineSpacing      = 5;
    
    CGFloat itemWidth = (screen_width - 25) / 4;
    _layout.itemSize = CGSizeMake(itemWidth, itemWidth);
    
    _cycleCollectionView = [[UICollectionView alloc]initWithFrame:self.view.bounds collectionViewLayout:_layout];
    _cycleCollectionView.backgroundColor = [UIColor whiteColor];
    _cycleCollectionView.delegate = self;
    _cycleCollectionView.dataSource = self;
    
    [_cycleCollectionView registerClass:[ZYImageViewCell class] forCellWithReuseIdentifier:ZYImageID];
    [self.view addSubview:_cycleCollectionView];
}



#pragma mark - UICollectionViewDataSource
- (NSInteger)collectionView:(UICollectionView *)collectionView numberOfItemsInSection:(NSInteger)section {
    return self.smaImagesArr.count;
}

- (UICollectionViewCell *)collectionView:(UICollectionView *)collectionView cellForItemAtIndexPath:(NSIndexPath *)indexPath {
    ZYImageViewCell * cell = [collectionView dequeueReusableCellWithReuseIdentifier:ZYImageID forIndexPath:indexPath];
    cell.image = self.smaImagesArr[indexPath.row];
    cell.indexPath = indexPath;
    cell.delegate = self;
    
    // 添加点击事件
    [cell.imageBtn addTarget:self action:@selector(imagesBtnClick:) forControlEvents:UIControlEventTouchUpInside];
    return cell;
}

- (void)imagesBtnClick:(UIButton *)btn {
    if (self.bigImagesArr.count == self.maxImages) {
        NSString * msg = [NSString stringWithFormat:@"最多只能选%ld张图片", self.maxImages];
        [self showAlertTitle:@"提示" andMessege:msg];
        return;
    }
    btn.selected = !btn.selected;
    if (btn.selected) {
        [self createBigImagesIndex:btn.tag-1];
    } else {
        [self.bigImagesArr removeObjectAtIndex:btn.tag];
    }
}

- (UIEdgeInsets)collectionView:(UICollectionView *)collectionView layout:(UICollectionViewLayout *)collectionViewLayout insetForSectionAtIndex:(NSInteger)section {
    return UIEdgeInsetsMake(5, 5, 5, 5);
}


#pragma mark 图片的点击事件响应协议
- (void)imagesClickIndexPath:(NSIndexPath *)indexPath {
    _cycleCollectionView.hidden = YES;
    self.navigationController.navigationBarHidden = YES;
    
    _zyView = [[ZYCollectionView alloc]initWithFrame:self.view.bounds];
    _zyView.smaImagesArr = self.smaImagesArr;
    _zyView.assets = self.assets;
    _zyView.index  = indexPath.row;

    [self.view addSubview:_zyView];
    [self setFinishBtn];
}

- (void)setFinishBtn {
    _finishBtn = [[UIButton alloc]initWithFrame:CGRectMake(30, screen_height - 50, 40, 20)];
    [_finishBtn setTitle:@"完成" forState:UIControlStateNormal];
    [_finishBtn setTitleColor:[UIColor redColor] forState:UIControlStateNormal];
    [_finishBtn addTarget:self action:@selector(btnClick) forControlEvents:UIControlEventTouchUpInside];
    [self.view addSubview:_finishBtn];
}

- (void)btnClick {
    _cycleCollectionView.hidden = NO;
    self.navigationController.navigationBarHidden = NO;
    [_zyView removeFromSuperview];
    [_finishBtn removeFromSuperview];
}


- (void)createBigImagesIndex:(NSInteger)index {
    for (int i = 0; i < self.assets.count; i++) {
        if (i == index) {
            PHAsset * asset = self.assets[i];
            CGSize size = CGSizeMake(asset.pixelWidth, asset.pixelHeight);
            PHImageRequestOptions * options = [[PHImageRequestOptions alloc] init];
            options.synchronous = YES;
            [[PHImageManager defaultManager] requestImageForAsset:asset targetSize:size contentMode:PHImageContentModeDefault options:options resultHandler:^(UIImage * _Nullable result, NSDictionary * _Nullable info) {
                ZYImageModel * model = [[ZYImageModel alloc]init];
                model.tag = index;
                model.images = result;
                [self.bigImagesArr addObject:model];
            }];
        }
    }
}

- (void)showAlertTitle:(NSString *)title andMessege:(NSString *)messege {
    UIAlertController * alterVc = [UIAlertController alertControllerWithTitle:title message:messege preferredStyle:UIAlertControllerStyleAlert];
    UIAlertAction * action = [UIAlertAction actionWithTitle:@"确定" style:UIAlertActionStyleCancel handler:nil];
    [alterVc addAction:action];
    [self presentViewController:alterVc animated:YES completion:nil];
}


- (void)btnClick:(UIButton *)btn {
    self.navigationController.navigationBarHidden = NO;
    _cycleCollectionView.hidden = NO;
    [btn removeFromSuperview];
}

- (NSMutableArray *)smaImagesArr{
    if (!_smaImagesArr) {
        _smaImagesArr = [[NSMutableArray alloc]init];
    }
    return _smaImagesArr;
}

- (NSMutableArray *)bigImagesArr {
    if (!_bigImagesArr) {
        _bigImagesArr = [[NSMutableArray alloc]init];
    }
    return _bigImagesArr;
}

- (AppDelegate *)app {
    if (!_app) {
        _app = [UIApplication sharedApplication].delegate;
    }
    return _app;
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}


@end
